{# Sidebar for displaying plugin widgets #}
{% if sidebar_widgets %}
<aside>
    {% for widget in sidebar_widgets %}
        <div class="sidebar-widget" {% if widget.identifier %}data-widget-id="{{ widget.identifier }}"{% endif %}>
            {% include widget.template with widget_context=widget.context %}
        </div>
    {% endfor %}
</aside>
{% endif %}
