from django.apps import AppConfig


class ThemeConfig(AppConfig):
    name = 'djadmin.plugins.theme'
    verbose_name = 'Django Admin Deux - Theme'
    default_auto_field = 'django.db.models.BigAutoField'
