{% extends "djadmin/admin_base.html" %}

{% block title %}{{ action.label }} - {{ opts.verbose_name }} - {{ block.super }}{% endblock %}

{% block content %}
  <article>
    <header>
      <h1>{{ action.label }} {{ opts.verbose_name }}</h1>
    </header>

    <div>
      {% block action_content %}{% endblock %}
    </div>
  </article>
{% endblock %}
