{% extends "djadmin/admin_base.html" %}
{% load static %}

{% block title %}
    Logged Out - {{ site_title|default:"Django Admin" }}
{% endblock %}

{% block extra_css %}
    {# Hardcoded CSS link because auth pages don't go through djadmin's asset management #}
    <link rel="stylesheet" href="{% static 'djadmin/theme/css/theme.css' %}">
{% endblock %}

{% block extra_js %}
    {# Hardcoded JS for dark mode toggle and mobile menu #}
    <script src="{% static 'djadmin/theme/js/admin.js' %}"></script>
{% endblock %}

{% block content %}
    <article class="auth">
        <header>
            <h1>Signed Out</h1>
        </header>

        <div>
            <p>You have successfully signed out.</p>
            <p><a href="{% url 'login' %}" class="primary">Sign in again</a></p>
        </div>
    </article>
{% endblock %}
