{% extends "djadmin/admin_base.html" %}

{% block title %}
    {{ app_verbose_name }} - {{ site_title|default:"Django Admin" }}
{% endblock %}

{% block content %}
    <article>
        <header>
            <h1>{{ app_verbose_name }}</h1>
        </header>

        <div>
            <table>
                <thead>
                    <tr>
                        <th>Model Admin</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    {% for item in model_admin_list %}
                        <tr>
                            <td>{{ item.display_name }}</td>
                            <td>
                                <menu>
                                    {% include "djadmin/includes/_action_buttons.html" with actions=item.general_actions default_css_class="primary" use_list_items=True %}
                                </menu>
                            </td>
                        </tr>
                    {% empty %}
                        <tr>
                            <td colspan="2">
                                <div>
                                    <p>No models registered for this app.</p>
                                </div>
                            </td>
                        </tr>
                    {% endfor %}
                </tbody>
            </table>
        </div>
    </article>
{% endblock %}
