{% extends "djadmin/base_action.html" %}

{% block action_content %}
  <div role="alert" class="warning">
    <p>{{ confirmation_message|default:"Are you sure you want to delete this item?" }}</p>

    {% if object %}
      <p><strong>{{ object }}</strong></p>
    {% endif %}
  </div>

  <form method="post">
    {% csrf_token %}

    <footer>
      <button type="submit" class="danger">Confirm {{ action.label }}</button>
      <a href="{{ list_url }}">Cancel</a>
    </footer>
  </form>
{% endblock %}
