{# Error template for unknown layout component types #}
<div role="alert" class="error">
    <strong>Unknown layout component</strong>
    <p>
        Layout component of type '<strong>{{ item_type }}</strong>' is not supported.
        Expected: Field, Fieldset, Row, or Collection.
    </p>
</div>
