{# Warning shown when Collection component is used without djadmin-formset plugin #}
<div role="alert">
    <strong>Inline editing not available</strong>
    <p>
        The '<strong>{{ collection.name }}</strong>' collection requires the djadmin-formset plugin.
        Install with: <code>pip install django-admin-deux[djadmin-formset]</code>
    </p>
</div>
