{# Render fields in a horizontal row #}
{% load djadmin_layout %}

<div class="form-row{% if row.css_classes %} {{ row.css_classes|join:' ' }}{% endif %}">
    {% for field_item in row.fields %}
        {% render_layout_item field_item %}
    {% endfor %}
</div>
