{% load djadmin_layout %}

{# Main layout renderer - iterates through layout items using data-driven template tag #}
<div class="form-layout">
    {% for item in layout.items %}
        {% render_layout_item item %}
    {% endfor %}
</div>
