{% load djadmin_tags %}{% for icon in icons %}{% if icon.url %}<a href="{{ icon.url }}" title="{{ icon.title }}" class="column-header-icon {% if icon.css_class %}{{ icon.css_class }}{% endif %}">{% include icon.icon_template %}</a>{% else %}<span title="{{ icon.title }}" class="column-header-icon {% if icon.css_class %}{{ icon.css_class }}{% endif %}">{% include icon.icon_template %}</span>{% endif %}{% endfor %}
